Learn R Programming

crevents (version 0.1.0)

crev_evrecs: Parse Crossref Events evidence records

Description

Parse Crossref Events evidence records

Usage

crev_evrecs(x, ...)

Arguments

x

(character) one or more urls for evidence records

...

curl options passed through to crul::verb-GET

Value

an unnamed list of results, one for each URL passed in.

Details

this function doesn't parse results other than converting JSON to an R list, because the data is deeply nested, so coercing to data.frame's is an exercise left to the user

From crev_query() you will get urls like "https://evidence.eventdata.crossref.org/evidence" in the $message$events$evidence_record slot of results. These links hold JSON data with the evidence record details for the record. This function simply retrieves that JSON and parses to a list

Examples

Run this code
# NOT RUN {
res <- crev_query(rows = 4)
recs <- res$message$events$evidence_record
crev_evrecs(recs[1])
crev_evrecs(recs)
# }

Run the code above in your browser using DataLab