this function doesn't parse results other than converting
JSON to an R list, because the data is deeply nested, so coercing
to data.frame's is an exercise left to the user
From crev_query() you will get urls like
"https://evidence.eventdata.crossref.org/evidence" in the
$message$events$evidence_record slot of results. These links
hold JSON data with the evidence record details for the record. This
function simply retrieves that JSON and parses to a list